@@ -1,7 +1,7 @@
 #coding=utf-8
 # -*- coding:utf-8 -*-
 
-from ..util import client,config, formater, oss_client, list2table, result_cache, sys_config
+from ..util import client,config, formater, oss_client, list2table, result_cache, sys_config,util
 from terminal import bold, magenta, gray, blue, green,red, yellow, confirm
 import json
 import os
@@ -21,7 +21,7 @@ def submit(cmd, cluster=DEFAULT_CLUSTER, timeout=172800, nodes=1, force=False, p
 
     job_desc['DAG']['Tasks']['cli-task']['Parameters']['Command']['CommandLine']=cmd
 
-    cluster = parse_cluster_cfg(cluster)
+    cluster = util.parse_cluster_cfg(cluster)
     for (k,v) in cluster.items():
         job_desc['DAG']['Tasks']['cli-task'][k]=v
 
@@ -46,12 +46,22 @@ def submit(cmd, cluster=DEFAULT_CLUSTER, timeout=172800, nodes=1, force=False, p
     rand = gen_rand_id()
 
     # pack, upload
+
     if pack:
         package_path = '%s%s/worker.tar.gz' % (pre_oss_path,rand)
-        folder_path = formater.get_abs_path(pack)
-        build_tar_and_upload(folder_path,package_path)
+        if ',' in pack:
+            arr = pack.split(',')
+            build_tar_from_arr_and_upload(arr, package_path)
+        else:
 
-        job_desc['DAG']['Tasks']['cli-task']['Parameters']['PackagePath'] = package_path
+            folder_path = formater.get_abs_path(pack)
+            if os.path.isdir(folder_path):
+                build_tar_from_dir_and_upload(folder_path, package_path)
+            else:
+               build_tar_from_arr_and_upload([pack],package_path)
+
+
+        job_desc['DAG']['Tasks']['cli-task']['Parameters']["Command"]['PackagePath'] = package_path
 
     job_desc['DAG']['Tasks']['cli-task']['Parameters']['StdoutRedirectPath'] = '%s%s/logs/' % (pre_oss_path,rand)
     job_desc['DAG']['Tasks']['cli-task']['Parameters']['StderrRedirectPath'] = '%s%s/logs/' % (pre_oss_path,rand)
@@ -59,6 +69,8 @@ def submit(cmd, cluster=DEFAULT_CLUSTER, timeout=172800, nodes=1, force=False, p
     if force:
         job_desc['JobFailOnInstanceFail'] = False
 
+    #print(job_desc)
+
     result = client.create_job(job_desc)
 
     if result.StatusCode==201:
@@ -94,7 +106,8 @@ def gen_job_desc():
                             "CommandLine": "",
                             "PackagePath": ""
                         }
-                    }
+                    },
+                    "WriteSupport": True
                 }
             },
             "Dependencies": {}
@@ -120,37 +133,6 @@ def trans_timeout(n):
     except:
         return 172800
 
-def parse_cluster_cfg(s):
-
-    if s.find('=')!=-1:
-        arr = s.split(':')
-        m={}
-        for item in arr:
-            [k,v]=item.split('=',1)
-            if k=='img':
-                m['ECSImageId']=v
-            if k=='type':
-                m['InstanceType']=v
-
-        m['ECSImageId']= m['ECSImageId'] if  m.get('ECSImageId') else IMG_ID
-        m['InstanceType']= m['InstanceType'] if  m.get('InstanceType') else INS_TYPE
-
-        if  not sys_config.get_instance_type_resrc(m['InstanceType']):
-            raise Exception('Invalid type(InstanceType), type "%s it" for more' % CMD)
-
-        print(gray('using AuthCluster: %s' % m))
-        return {'AutoCluster':m}
-    else:
-        result = client.list_clusters()
-        clusters = result.get('Items')
-        for c in clusters:
-            if c.get('Id')==s:
-                print(gray('using Cluster: %s' % s))
-                return {'ClusterId':s}
-        raise Exception('Invalid ClusterId, type "%s c" for more' % CMD)
-
-
-
 
 def trans_env(s):
     if not s:
@@ -188,7 +170,7 @@ def gen_rand_id():
 
 
 
-def build_tar_and_upload(folder_path, oss_path):
+def build_tar_from_dir_and_upload(folder_path, oss_path):
     '''
     pack program files, and upload to oss_path
     :param folder_path:
@@ -200,7 +182,7 @@ def build_tar_and_upload(folder_path, oss_path):
 
 
     # cd
-    os.chdir(folder_path)
+    #os.chdir(folder_path)
 
     # tar
     print('pack %s' % dist)
@@ -215,3 +197,17 @@ def build_tar_and_upload(folder_path, oss_path):
     print('Upload: %s ==> %s' % (dist, oss_path))
     oss_client.upload_file( dist, oss_path)
 
+
+def build_tar_from_arr_and_upload(arr, oss_path):
+    dist = os.path.join(os.getcwd(), 'worker.tar.gz')
+
+     # tar
+    print('pack %s' % dist)
+    with tarfile.open(dist, 'w|gz') as tar:
+        for file in arr:
+            fullpath = formater.get_abs_path(file)
+            print('add %s' % fullpath)
+            tar.add(fullpath,arcname=file)
+    # upload
+    print('Upload: %s ==> %s' % (dist, oss_path))
+    oss_client.upload_file( dist, oss_path)
\ No newline at end of file
