@@ -1,4 +1,4 @@
-from ..util import result_cache, ossclient, formater, client
+from ..util import result_cache, oss_client, formater, client
 from terminal import gray,green,red
 import os
 from oss2.exceptions import NoSuchKey,NoSuchBucket
@@ -67,7 +67,7 @@ def batch_fetch_logs(oss_path_arr, dir_path):
         print('Download %s' % gray(oss_path) )
 
         try:
-            ossclient.fetch_content_to_file(oss_path, os.path.join(dir_path,file_name))
+            oss_client.download_file(oss_path, os.path.join(dir_path,file_name))
         except Exception as e:
             if not isinstance(e, NoSuchKey) and not isinstance(e, NoSuchBucket):
                 raise e
\ No newline at end of file
