@@ -1,5 +1,6 @@
 import os
 from ..util import client, zip,oss_client
+from ..const import IMG_ID,INS_TYPE
 from terminal import green,gray
 import re
 import json
@@ -53,11 +54,24 @@ def create(project_name, location=None, type='empty',job=None ):
         zip.unzip_file('%s.zip' % src, dist)
 
         # update job.json set imageId: m-28sm4m6ez
-        
+        update_image_n_instype(os.path.join(dist,'job.json'))
 
     print(green('Done'))
     print(gray('Type "cd %s && %s p st" to show project detail\n' % (project_name,CMD)))
 
+def update_image_n_instype(p):
+    obj = {}
+    with open(p, 'r') as f:
+        obj = json.loads(f.read())
+
+
+    with open(p, 'w') as f:
+        ts = obj['DAG']['Tasks']
+        for k in ts:
+            ts[k]['AutoCluster']['ECSImageId']=IMG_ID
+            ts[k]['AutoCluster']['InstanceType']=INS_TYPE
+        f.write(json.dumps(obj, indent=2))
+
 def download_worker(packageUri, dist):
     src = os.path.join(dist, 'src')
     os.mkdir(src)
