@@ -78,13 +78,16 @@ def init(cmd_project):
                              usage='''Usage: %s project|p update [task] [option]
 
       Examples:
-          1. %s p update -c img=%s:type=ecs.s3.large  # update all tasks, set AutoCluster
-          2. %s p update -c cls-000010102             # update all tasks, set ClusterId
-          3. %s p update find -c cls-000010102        # update find task only
-          4. %s p update find -c cls-000010102        # update find task only''' % (
+          1. %s p update -c img=%s:type=ecs.s3.large                            # update all tasks, set AutoCluster
+          2. %s p update -c cls-000010102                                       # update all tasks, set ClusterId
+          3. %s p update find -c cls-000010102                                  # update find task only
+          4. %s p update -d oss://your-bucket/dockers/:localhost:5000/myubuntu  # update all task use docker ''' % (
                              COMMAND, CMD, IMG_ID, CMD, CMD,CMD),
                              func=project_update.update)
-    cmd_project_update.option("-c, --cluster [cluster]", MSG['project']['update']['option']['cluster'])
+    cmd_project_update.option("-c, --cluster [cluster]", MSG['project']['update']['option']['cluster'],
+                              resolve=project_update.trans_cluster)
+    cmd_project_update.option("-d, --docker [docker_path]", MSG['project']['update']['option']['docker'],
+                              resolve=project_update.trans_docker)
     cmd_project.action(cmd_project_update)
 
 
