@@ -125,10 +125,12 @@ def getJSON():
             'update': {
                 'description': 'update job.json',
                 'option': {
-                    'cluster': """should be a cluster_id, or an auto_cluster string.
-                              default value is an auto_cluster string: img=%s:type=%s.
-                              you can use a exists cluster(type '%s c' for more cluster id),
-                              or use auto cluster, format: img=<imageId>:type=<instanceType> (instanceType default: %s, type '%s it' for more instanceType). """
+                    'cluster': """optional, should be a cluster_id, or an auto_cluster string.
+                                 default value is an auto_cluster string: img=%s:type=%s.
+                                 you can use a exists cluster(type '%s c' for more cluster id),
+                                 or use auto cluster, format: img=<imageId>:type=<instanceType> (instanceType default: %s, type '%s it' for more instanceType). """
+                    % (IMG_ID, INS_TYPE, CMD, INS_TYPE, CMD),
+                    "docker": """optional, use docker image to run, format:<oss_docker_storage_path>:<docker_name>"""
                 }
             },
             'submit':{
@@ -141,10 +143,11 @@ def getJSON():
                 'description': 'add a task',
                 'detail': "add a task node into job.json, and create a promgram(python) file in src folder.",
                 'option': {
-                    'cluster': """should be a cluster_id, or an auto_cluster string.
-                                  default value is an auto_cluster string: img=%s:type=%s.
-                                  you can use a exists cluster(type '%s c' for more cluster id),
-                                  or use auto cluster, format: img=<imageId>:type=<instanceType> (instanceType default: %s, type '%s it' for more instanceType). """,
+                    'cluster': """optional, should be a cluster_id, or an auto_cluster string.
+                                 default value is an auto_cluster string: img=%s:type=%s.
+                                 you can use a exists cluster(type '%s c' for more cluster id),
+                                 or use auto cluster, format: img=<imageId>:type=<instanceType> (instanceType default: %s, type '%s it' for more instanceType).  """
+                    % (IMG_ID, INS_TYPE, CMD, INS_TYPE, CMD),
 
                     'docker': 'docker image name, must tag with prefix:"localhost:5000/", type "docker images" for more'
                 }
