@@ -130,7 +130,9 @@ def getJSON():
                     'cluster': """可以使一个集群ID或者AutoCluster配置字符串.
                               默认是一个AutoCluster配置字符串: img=%s:type=%s.
                               你可以使用一个已经存在的集群ID(type '%s c' for more cluster id),
-                              或者可以使用AutoCluster配置字符串, 格式: img=<imageId>:type=<instanceType> (运行这个: '%s it' 可以看到更多instanceType). """ % (IMG_ID, INS_TYPE, CMD, CMD)
+                              或者可以使用AutoCluster配置字符串, 格式: img=<imageId>:type=<instanceType> (运行这个: '%s it' 可以看到更多instanceType). """
+                               % (IMG_ID, INS_TYPE, CMD, CMD),
+                    "docker": """可选,使用docker镜像运行, 格式如:<oss_docker_storage_path>:<docker_name>"""
                 }
             },
             'submit':{
@@ -146,7 +148,8 @@ def getJSON():
                     'cluster': """可以使一个集群ID或者AutoCluster配置字符串.
                                   默认是一个AutoCluster配置字符串: img=%s:type=%s.
                                   你可以使用一个已经存在的集群ID(type '%s c' for more cluster id),
-                                  或者可以使用AutoCluster配置字符串, 格式: img=<imageId>:type=<instanceType> (运行这个: '%s it' 可以看到更多instanceType). """ % (IMG_ID, INS_TYPE, CMD, CMD),
+                                  或者可以使用AutoCluster配置字符串, 格式: img=<imageId>:type=<instanceType> (运行这个: '%s it' 可以看到更多instanceType). """
+                               % (IMG_ID, INS_TYPE, CMD, CMD),
 
                     'docker': 'Docker镜像名, 需要以前缀"localhost:5000/"打tag'
                 }
